diff libpurple/protocols/msn/switchboard.h @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 83f10ac192d9 60bc06498746
line wrap: on
line diff
--- a/libpurple/protocols/msn/switchboard.h	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/msn/switchboard.h	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * @file switchboard.h MSN switchboard functions
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -76,7 +76,7 @@
 	char *auth_key;
 	char *session_id;
 
-	GaimConversation *conv; /**< The conversation that displays the
+	PurpleConversation *conv; /**< The conversation that displays the
 							  messages of this switchboard, or @c NULL if
 							  this is a helper switchboard. */
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.